==> qcad-3.5.1.0_2.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--exact match--
--file: es.po--
Desagrupa Entidades de Texto en Letras sencillas
Selecciona entidades solas</translatorcomment>
        <translation type="obsolete">Sencillo</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dos: Vertical</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dos: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tres: Derecho</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tres: Izquierda</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tres: Por encima de</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tres: Por debajo de</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tres: Vertical</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tres: Horizontal</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuatro: Igual</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuatro: Derecho</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuatro: Izquierda</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espaciado de la rejilla &lt; Meta espaciado de rejilla</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Cuatro: Igual</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Cuatro: Izquierda</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Cuatro: Derecho</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Sencillo</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Tres: Por debajo de</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Tres: Horizontal</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Tres: Vertical</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Dos: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Dos: Vertical</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+320"/>
        <source>Grid</source>
        <translation>Rejilla</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fin</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>En entidad</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translatorcomment>--exact match--
--file: artisan_es.ts--
&amp;Perpendicular
Perpendicular</translatorcomment>
        <translation>Perpendicular</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersección</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Referencia</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaciado de la rejilla &lt; Meta espaciado de rejilla</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaciado de la rejilla &lt; Meta espaciado de rejilla</translation>
    </message>
</context>
</TS>

==> qcad-3.15.2.0.txz: usr/local/share/qcad/scripts/Widgets/Viewport/ts/Viewport_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es_ES">
<context>
    <name>Form</name>
    <message>
        <source>Single</source>
        <translatorcomment>--exact match--
--file: es.po--
Desagrupa Entidades de Texto en Letras sencillas
Selecciona entidades solas</translatorcomment>
        <translation type="obsolete">Sencillo</translation>
    </message>
    <message>
        <source>Two: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dos: Vertical</translation>
    </message>
    <message>
        <source>Two: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Dos: Horizontal</translation>
    </message>
    <message>
        <location filename="../Templates/20_ThreeRight.ui" line="+14"/>
        <source>Three: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tres: Derecho</translation>
    </message>
    <message>
        <location filename="../Templates/21_ThreeLeft.ui" line="+14"/>
        <source>Three: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tres: Izquierda</translation>
    </message>
    <message>
        <location filename="../Templates/22_ThreeAbove.ui" line="+14"/>
        <source>Three: Above</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Tres: Por encima de</translation>
    </message>
    <message>
        <source>Three: Below</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tres: Por debajo de</translation>
    </message>
    <message>
        <source>Three: Vertical</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tres: Vertical</translation>
    </message>
    <message>
        <source>Three: Horizontal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Tres: Horizontal</translation>
    </message>
    <message>
        <source>Four: Equal</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuatro: Igual</translation>
    </message>
    <message>
        <source>Four: Right</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuatro: Derecho</translation>
    </message>
    <message>
        <source>Four: Left</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Cuatro: Izquierda</translation>
    </message>
    <message>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Espaciado de la rejilla &lt; Meta espaciado de rejilla</translation>
    </message>
</context>
<context>
    <name>FourEqual</name>
    <message>
        <location filename="../Templates/30_FourEqual.ui" line="+14"/>
        <source>Four: Equal</source>
        <translation>Cuatro: Igual</translation>
    </message>
</context>
<context>
    <name>FourLeft</name>
    <message>
        <location filename="../Templates/32_FourLeft.ui" line="+14"/>
        <source>Four: Left</source>
        <translation>Cuatro: Izquierda</translation>
    </message>
</context>
<context>
    <name>FourRight</name>
    <message>
        <location filename="../Templates/31_FourRight.ui" line="+14"/>
        <source>Four: Right</source>
        <translation>Cuatro: Derecho</translation>
    </message>
</context>
<context>
    <name>Single</name>
    <message>
        <location filename="../Templates/00_Single.ui" line="+14"/>
        <source>Single</source>
        <translation>Sencillo</translation>
    </message>
</context>
<context>
    <name>ThreeBelow</name>
    <message>
        <location filename="../Templates/23_ThreeBelow.ui" line="+14"/>
        <source>Three: Below</source>
        <translation>Tres: Por debajo de</translation>
    </message>
</context>
<context>
    <name>ThreeHorizontal</name>
    <message>
        <location filename="../Templates/25_ThreeHorizontal.ui" line="+14"/>
        <source>Three: Horizontal</source>
        <translation>Tres: Horizontal</translation>
    </message>
</context>
<context>
    <name>ThreeVertical</name>
    <message>
        <location filename="../Templates/24_ThreeVertical.ui" line="+14"/>
        <source>Three: Vertical</source>
        <translation>Tres: Vertical</translation>
    </message>
</context>
<context>
    <name>TwoHorizontal</name>
    <message>
        <location filename="../Templates/11_TwoHorizontal.ui" line="+14"/>
        <source>Two: Horizontal</source>
        <translation>Dos: Horizontal</translation>
    </message>
</context>
<context>
    <name>TwoVertical</name>
    <message>
        <location filename="../Templates/10_TwoVertical.ui" line="+14"/>
        <source>Two: Vertical</source>
        <translation>Dos: Vertical</translation>
    </message>
</context>
<context>
    <name>Viewport</name>
    <message>
        <location filename="../Viewport.js" line="+252"/>
        <source>Dropped data not supported</source>
        <translation>Datos insertados no compatibles</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Importing file: </source>
        <translation>Importación de archivo: </translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Importing URL: </source>
        <translation>Importación de URL: </translation>
    </message>
    <message>
        <source>Grid</source>
        <translation type="vanished">Rejilla</translation>
    </message>
    <message>
        <source>End</source>
        <translation type="vanished">Fin</translation>
    </message>
    <message>
        <source>On Entity</source>
        <translation type="vanished">En entidad</translation>
    </message>
    <message>
        <source>Perpendicular</source>
        <translatorcomment>--exact match--
--file: artisan_es.ts--
&amp;Perpendicular
Perpendicular</translatorcomment>
        <translation type="vanished">Perpendicular</translation>
    </message>
    <message>
        <source>Tangential</source>
        <translation type="vanished">Tangencial</translation>
    </message>
    <message>
        <source>Center</source>
        <translation type="vanished">Centro</translation>
    </message>
    <message>
        <source>Middle</source>
        <translation type="vanished">Medio</translation>
    </message>
    <message>
        <source>Intersection</source>
        <translation type="vanished">Intersección</translation>
    </message>
    <message>
        <source>Reference</source>
        <translation type="vanished">Referencia</translation>
    </message>
    <message>
        <location filename="../Viewport.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaciado de la rejilla &lt; Meta espaciado de rejilla</translation>
    </message>
</context>
<context>
    <name>ViewportGl</name>
    <message>
        <location filename="../ViewportGl.ui" line="+99"/>
        <source>Grid Spacing &lt; Meta Grid Spacing</source>
        <translation>Espaciado de la rejilla &lt; Meta espaciado de rejilla</translation>
    </message>
</context>
</TS>
